@@ -8,14 +8,12 @@
 #' The user may want to use [toupper()] or [tolower()]
 #' to ensure the case matches.
 #'
-#' @inheritParams chk_flag
-#' @param ext A character vector of the permitted file extensions (without the .).
+#' @inheritParams params
 #' @return
 #' The `chk_` function throws an informative error if the test fails.
 #'
 #' The `vld_` function returns a flag indicating whether the test was met.
 #'
-#'
 #' @family chk_files
 #' @export
 #'
@@ -24,13 +22,15 @@
 #' # chk_ext
 #' try(chk_ext("file1.pdf", "png"))
 chk_ext <- function(x, ext, x_name = NULL) {
-  if(vld_ext(x, ext)) {
+  if (vld_ext(x, ext)) {
     return(invisible())
   }
-  if(is.null(x_name)) x_name <- deparse_backtick_chk(substitute(x))
+  if (is.null(x_name)) x_name <- deparse_backtick_chk(substitute(x))
   chk_string(x, x_name = x_name)
-  abort_chk(x_name, " must have extension ", cc(ext, " or "), " (not '",
-    tools::file_ext(x), "')")
+  abort_chk(
+    x_name, " must have extension ", cc(ext, " or "), " (not '",
+    tools::file_ext(x), "')"
+  )
 }
 
 #' @describeIn chk_ext Validate File Extension
